@@ -2,7 +2,9 @@
 IBM Confidential
 OCO Source Materials
 (C) Copyright IBM Corporation 2019 All Rights Reserved
-The source code for this program is not published or otherwise divested of its trade secrets, irrespective of what has been deposited with the U.S. Copyright Office.
+The source code for this program is not published or otherwise divested of its trade secrets,
+irrespective of what has been deposited with the U.S. Copyright Office.
+Copyright (c) 2020 Red Hat, Inc.
 */
 
 package transforms
@@ -10,7 +12,7 @@ package transforms
 import (
 	"testing"
 
-	app "github.com/IBM/multicloud-operators-subscription-release/pkg/apis/app/v1alpha1"
+	app "github.com/open-cluster-management/multicloud-operators-subscription-release/pkg/apis/apps/v1"
 )
 
 //TODO: Might have to update the json for testing once we have a live example
@@ -19,7 +21,7 @@ func TestTransformAppHelmCR(t *testing.T) {
 
 	UnmarshalFile("apphelmcr.json", &a, t)
 
-	node := AppHelmCRResource{&a}.BuildNode()
+	node := AppHelmCRResourceBuilder(&a).BuildNode()
 
 	// Test only the fields that exist in HelmRelease - the common test will test the other bits
 	AssertEqual("name", node.Properties["name"], "testAppHelmCR", t)
