@@ -2,7 +2,9 @@
 IBM Confidential
 OCO Source Materials
 (C) Copyright IBM Corporation 2019 All Rights Reserved
-The source code for this program is not published or otherwise divested of its trade secrets, irrespective of what has been deposited with the U.S. Copyright Office.
+The source code for this program is not published or otherwise divested of its trade secrets,
+irrespective of what has been deposited with the U.S. Copyright Office.
+Copyright (c) 2020 Red Hat, Inc.
 */
 
 package transforms
@@ -10,13 +12,13 @@ package transforms
 import (
 	"testing"
 
-	app "github.com/IBM/multicloud-operators-channel/pkg/apis/app/v1alpha1"
+	app "github.com/open-cluster-management/multicloud-operators-channel/pkg/apis/apps/v1"
 )
 
 func TestTransformChannel(t *testing.T) {
 	var c app.Channel
 	UnmarshalFile("channel.json", &c, t)
-	node := ChannelResource{&c}.BuildNode()
+	node := ChannelResourceBuilder(&c).BuildNode()
 
 	// Test only the fields that exist in channel - the common test will test the other bits
 	AssertEqual("kind", node.Properties["kind"], "Channel", t)
