@@ -2,7 +2,9 @@
 IBM Confidential
 OCO Source Materials
 (C) Copyright IBM Corporation 2019 All Rights Reserved
-The source code for this program is not published or otherwise divested of its trade secrets, irrespective of what has been deposited with the U.S. Copyright Office.
+The source code for this program is not published or otherwise divested of its trade secrets,
+irrespective of what has been deposited with the U.S. Copyright Office.
+Copyright (c) 2020 Red Hat, Inc.
 */
 
 package transforms
@@ -15,7 +17,6 @@ import (
 	"github.com/open-cluster-management/search-collector/pkg/config"
 	machineryV1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	apiTypes "k8s.io/apimachinery/pkg/types"
 )
 
@@ -62,63 +63,21 @@ func transformCommon(resource machineryV1.Object) Node {
 		Metadata:   make(map[string]string),
 	}
 	n.Metadata["OwnerUID"] = ownerRefUID(resource.GetOwnerReferences())
+	//Adding OwnerReleaseName and Namespace for the resources that doesn't have ownerRef, but are deployed by a release
+	if n.Metadata["OwnerUID"] == "" && resource.GetAnnotations()["meta.helm.sh/release-name"] != "" && resource.GetAnnotations()["meta.helm.sh/release-namespace"] != "" {
+		n.Metadata["OwnerReleaseName"] = resource.GetAnnotations()["meta.helm.sh/release-name"]
+		n.Metadata["OwnerReleaseNamespace"] = resource.GetAnnotations()["meta.helm.sh/release-namespace"]
+	}
 	return n
 }
 
-// Extracts the properties from a non-default k8s resource and returns them in a map ready to be put in an Node
-func unstructuredProperties(resource UnstructuredResource) map[string]interface{} {
-	ret := make(map[string]interface{})
-
-	ret["kind"] = resource.GetKind()
-	ret["name"] = resource.GetName()
-	ret["selfLink"] = resource.GetSelfLink()
-	ret["created"] = resource.GetCreationTimestamp().UTC().Format(time.RFC3339)
-	ret["_clusterNamespace"] = config.Cfg.ClusterNamespace
-	if config.Cfg.DeployedInHub {
-		ret["_hubClusterResource"] = true
+func addReleaseOwnerUID(node Node, ns NodeStore) {
+	releaseNode, ok := ns.ByKindNamespaceName["HelmRelease"][node.GetMetadata("OwnerReleaseNamespace")][node.GetMetadata("OwnerReleaseName")]
+	if ok { // If the HelmRelease node is in the list of current nodes
+		node.Metadata["OwnerUID"] = releaseNode.UID
+	} else {
+		glog.V(3).Info("Release node not found with kind:HelmRelease, namespace: ", node.GetMetadata("OwnerReleaseNamespace"), " name: ", node.GetMetadata("OwnerReleaseName"))
 	}
-
-	// valid api group with have format of "apigroup/version"
-	// unnamed api groups will have format of "/version"
-	slice := strings.Split(resource.GetAPIVersion(), "/")
-	if len(slice) == 2 {
-		ret["apigroup"] = slice[0]
-		ret["apiversion"] = slice[1]
-	}
-
-	if resource.GetLabels() != nil {
-		ret["label"] = resource.GetLabels()
-	}
-	if resource.GetNamespace() != "" {
-		ret["namespace"] = resource.GetNamespace()
-	}
-	if resource.GetAnnotations()["apps.open-cluster-management.io/hosting-subscription"] != "" {
-		ret["_hostingSubscription"] = resource.GetAnnotations()["apps.open-cluster-management.io/hosting-subscription"]
-	}
-	if resource.GetAnnotations()["apps.open-cluster-management.io/hosting-deployable"] != "" {
-		ret["_hostingDeployable"] = resource.GetAnnotations()["apps.open-cluster-management.io/hosting-deployable"]
-	}
-	return ret
-
-}
-
-type UnstructuredResource struct {
-	*unstructured.Unstructured
-}
-
-func (u UnstructuredResource) BuildNode() Node {
-	n := Node{
-		UID:        prefixedUID(u.GetUID()),
-		Properties: unstructuredProperties(u),
-		Metadata:   make(map[string]string),
-	}
-	n.Metadata["OwnerUID"] = ownerRefUID(u.GetOwnerReferences())
-	return n
-}
-
-func (u UnstructuredResource) BuildEdges(ns NodeStore) []Edge {
-	// The deployer subscriber edges will be made through CommonEdges
-	return []Edge{}
 }
 
 func CommonEdges(uid string, ns NodeStore) []Edge {
@@ -131,12 +90,15 @@ func CommonEdges(uid string, ns NodeStore) []Edge {
 	} else { // If namespace property is not present, nodeTripleMap assigns namespace to be _NONE in reconciler (reconciler.go:47)
 		namespace = "_NONE"
 	}
-
+	if currNode.Metadata["OwnerUID"] == "" && currNode.Metadata["OwnerReleaseName"] != "" && currNode.Metadata["OwnerReleaseNamespace"] != "" {
+		addReleaseOwnerUID(currNode, ns) //add OwnerUID for resources deployed by HelmRelease, but doesn't have an associated ownerRef
+		//mostly cluster-scoped resources like ClusterRole and ClusterRoleBinding
+	}
 	nodeInfo := NodeInfo{Name: currNode.Properties["name"].(string), NameSpace: namespace, UID: uid, EdgeType: "ownedBy", Kind: kind}
 
 	//ownedBy edges
 	if currNode.GetMetadata("OwnerUID") != "" {
-		ret = append(ret, edgesByOwner(currNode.GetMetadata("OwnerUID"), ns, nodeInfo)...)
+		ret = append(ret, edgesByOwner(currNode.GetMetadata("OwnerUID"), ns, nodeInfo, []string{})...)
 	}
 
 	//deployer subscriber edges
@@ -172,8 +134,13 @@ type NodeInfo struct {
 
 // Function to create an edge between the pod and it's owner, if it exists
 // If the pod is owned by a replicaset which in turn is owned by a deployment, the function will be recursively called to create edges between pod->replicaset and pod->deployment
-func edgesByOwner(destUID string, ns NodeStore, nodeInfo NodeInfo) []Edge {
+func edgesByOwner(destUID string, ns NodeStore, nodeInfo NodeInfo, seenDests []string) []Edge {
 	ret := []Edge{}
+	for _, value := range seenDests {
+		if value == destUID {
+			return ret
+		}
+	}
 	if destUID != "" {
 		//Lookup by UID to see if the owner Node exists
 		if dest, ok := ns.ByUID[destUID]; ok {
@@ -185,7 +152,7 @@ func edgesByOwner(destUID string, ns NodeStore, nodeInfo NodeInfo) []Edge {
 					SourceKind: nodeInfo.Kind,
 					DestKind:   dest.Properties["kind"].(string),
 				})
-
+				seenDests = append(seenDests, destUID)    //add destUID to processed/seen destinations
 				if dest.GetMetadata("ReleaseUID") != "" { // If owner included/owned by a release...
 					if _, ok := ns.ByUID[dest.GetMetadata("ReleaseUID")]; ok { // ...make sure the release exists...
 						if nodeInfo.UID != dest.GetMetadata("ReleaseUID") { //avoid connecting node to itself
@@ -203,19 +170,26 @@ func edgesByOwner(destUID string, ns NodeStore, nodeInfo NodeInfo) []Edge {
 				// If the destination node has property _ownerUID, create an edge between the pod and the destination's owner
 				// Call the edgesByOwner recursively to create the ownedBy edge
 				if dest.GetMetadata("OwnerUID") != "" {
-					ret = append(ret, edgesByOwner(dest.GetMetadata("OwnerUID"), ns, nodeInfo)...)
+					ret = append(ret, edgesByOwner(dest.GetMetadata("OwnerUID"), ns, nodeInfo, seenDests)...)
 				}
 			}
 		} else {
-			glog.V(2).Infof("For %s, %s, %s edge not created: ownerUID %s not found", nodeInfo.Kind, nodeInfo.NameSpace+"/"+nodeInfo.Name, nodeInfo.EdgeType, destUID)
+			glog.V(4).Infof("For %s, %s, %s edge not created: ownerUID %s not found", nodeInfo.Kind, nodeInfo.NameSpace+"/"+nodeInfo.Name, nodeInfo.EdgeType, destUID)
 		}
 	}
 	return ret
 }
 
 // Function used to get all edges for a specific destKind - the propSet are maps of resource names, nodeInfo has additional info about the node and nodestore has all the current nodes
-func edgesByDestinationName(propSet map[string]struct{}, destKind string, nodeInfo NodeInfo, ns NodeStore) []Edge {
+func edgesByDestinationName(propSet map[string]struct{}, destKind string, nodeInfo NodeInfo, ns NodeStore, seenDests []string) []Edge {
 	ret := []Edge{}
+	for _, value := range seenDests {
+		//Checking against nodeInfo.UID - it gets updated every time edgesByDestinationName is called
+		if value == nodeInfo.UID {
+			return ret
+		}
+	}
+
 	if len(propSet) > 0 {
 		for name := range propSet {
 			// For channels/subscriptions/deployables/applications, get the namespace and name from each string, if present. Else, assume it is in the node's namespace
@@ -227,7 +201,7 @@ func edgesByDestinationName(propSet map[string]struct{}, destKind string, nodeIn
 				} else if len(destKindInfo) == 1 {
 					name = destKindInfo[0]
 				} else {
-					glog.V(2).Infof("For %s, %s edge not created as %s is not in namespace/name format", nodeInfo.NameSpace+"/"+nodeInfo.Kind+"/"+nodeInfo.Name, nodeInfo.EdgeType, destKind+"/"+name)
+					glog.V(4).Infof("For %s, %s edge not created as %s is not in namespace/name format", nodeInfo.NameSpace+"/"+nodeInfo.Kind+"/"+nodeInfo.Name, nodeInfo.EdgeType, destKind+"/"+name)
 					continue
 				}
 			}
@@ -259,9 +233,11 @@ func edgesByDestinationName(propSet map[string]struct{}, destKind string, nodeIn
 					}
 				}
 			} else {
-				glog.V(2).Infof("For %s, %s edge not created as %s named %s not found", nodeInfo.NameSpace+"/"+nodeInfo.Kind+"/"+nodeInfo.Name, nodeInfo.EdgeType, destKind, nodeInfo.NameSpace+"/"+name)
+				glog.V(4).Infof("For %s, %s edge not created as %s named %s not found", nodeInfo.NameSpace+"/"+nodeInfo.Kind+"/"+nodeInfo.Name, nodeInfo.EdgeType, destKind, nodeInfo.NameSpace+"/"+name)
 			}
 		}
+		seenDests = append(seenDests, nodeInfo.UID) //add nodeInfo UID to processed/seen nodes
+
 		// If the destination node has property _ownerUID, create an edge between the pod and the destination's owner
 		// Call the edgesByOwner recursively to create the uses edge
 		if nodeInfo.Kind != "Deployable" { //Adding this edge case to avoid duplicating edges between subscription to placementrules and applications
@@ -272,7 +248,7 @@ func edgesByDestinationName(propSet map[string]struct{}, destKind string, nodeIn
 						nodeInfo.UID = nextSrc.GetMetadata("OwnerUID")
 						nodeInfo.Kind = nextSrcOwner.Properties["kind"].(string)
 						nodeInfo.EdgeType = "uses"
-						ret = append(ret, edgesByDestinationName(propSet, destKind, nodeInfo, ns)...)
+						ret = append(ret, edgesByDestinationName(propSet, destKind, nodeInfo, ns, seenDests)...)
 					}
 				}
 			}
@@ -311,17 +287,24 @@ func edgesByDeployerSubscriber(nodeInfo NodeInfo, ns NodeStore) []Edge {
 					}
 				}
 			} else {
-				glog.V(2).Infof("For %s, %s edge not created as %s named %s not found", nodeInfo.NameSpace+"/"+nodeInfo.Kind+"/"+nodeInfo.Name, nodeInfo.EdgeType, destKind, namespace+"/"+name)
+				glog.V(4).Infof("For %s, %s edge not created as %s named %s not found", nodeInfo.NameSpace+"/"+nodeInfo.Kind+"/"+nodeInfo.Name, nodeInfo.EdgeType, destKind, namespace+"/"+name)
 			}
 		} else {
-			glog.V(2).Infof("For %s, %s edge not created as %s is not in namespace/name format", nodeInfo.NameSpace+"/"+nodeInfo.Kind+"/"+nodeInfo.Name, nodeInfo.EdgeType, destNsName)
+			glog.V(4).Infof("For %s, %s edge not created as %s is not in namespace/name format", nodeInfo.NameSpace+"/"+nodeInfo.Kind+"/"+nodeInfo.Name, nodeInfo.EdgeType, destNsName)
 		}
 		return depSubedges
 	}
 
 	//Inner function to call edgesByDepSub for creating edges from node to hosting deployable/subscription - recursively calls with the owner's properties if the incoming node doesn't have them
 	var findSub func(string) []Edge
+	var seenDests []string
 	findSub = func(UID string) []Edge {
+		//Checking against UID - it gets updated every time findSub is called
+		for _, value := range seenDests {
+			if value == UID {
+				return ret
+			}
+		}
 		subscription := ""
 		deployable := ""
 		if node, ok := ns.ByUID[UID]; ok {
@@ -333,6 +316,8 @@ func edgesByDeployerSubscriber(nodeInfo NodeInfo, ns NodeStore) []Edge {
 				nodeInfo.EdgeType = "definedBy"
 				ret = append(ret, edgesByDepSub(deployable, "Deployable")...)
 			}
+			seenDests = append(seenDests, UID) //add UID to processed/seen destinations
+
 			// Recursively call the function with ownerUID, if the node doesn't have hosting deployable/subscription properties but has an owner reference.
 			// This is mainly to create edges from pods to subscription/deployable, when the hosting deployable/subscription properties are not in pods, but present in deployments
 			if subscription == "" && deployable == "" {
@@ -360,7 +345,7 @@ func edgesToApplication(nodeInfo NodeInfo, ns NodeStore, UID string, onlyApplica
 		for _, app := range strings.Split(subNode.GetMetadata("_hostingApplication"), ",") {
 			applicationMap[app] = struct{}{}
 		}
-		ret = append(ret, edgesByDestinationName(applicationMap, "Application", nodeInfo, ns)...)
+		ret = append(ret, edgesByDestinationName(applicationMap, "Application", nodeInfo, ns, []string{})...)
 	}
 	if !onlyApplication {
 		if subNode.GetMetadata("_channels") != "" {
@@ -368,7 +353,7 @@ func edgesToApplication(nodeInfo NodeInfo, ns NodeStore, UID string, onlyApplica
 			for _, channel := range strings.Split(subNode.GetMetadata("_channels"), ",") {
 				channelMap[channel] = struct{}{}
 			}
-			ret = append(ret, edgesByDestinationName(channelMap, "Channel", nodeInfo, ns)...)
+			ret = append(ret, edgesByDestinationName(channelMap, "Channel", nodeInfo, ns, []string{})...)
 		}
 	}
 	return ret
