@@ -2,7 +2,9 @@
 IBM Confidential
 OCO Source Materials
 (C) Copyright IBM Corporation 2019 All Rights Reserved
-The source code for this program is not published or otherwise divested of its trade secrets, irrespective of what has been deposited with the U.S. Copyright Office.
+The source code for this program is not published or otherwise divested of its trade secrets,
+irrespective of what has been deposited with the U.S. Copyright Office.
+Copyright (c) 2020 Red Hat, Inc.
 */
 
 package transforms
@@ -17,7 +19,7 @@ import (
 func TestTransformCronJob(t *testing.T) {
 	var c v1.CronJob
 	UnmarshalFile("cronjob.json", &c, t)
-	node := CronJobResource{&c}.BuildNode()
+	node := CronJobResourceBuilder(&c).BuildNode()
 
 	// Build time struct matching time in test data
 	date := time.Date(2019, 3, 5, 23, 30, 0, 0, time.UTC)
