@@ -2,20 +2,24 @@
 IBM Confidential
 OCO Source Materials
 (C) Copyright IBM Corporation 2019 All Rights Reserved
-The source code for this program is not published or otherwise divested of its trade secrets, irrespective of what has been deposited with the U.S. Copyright Office.
+The source code for this program is not published or otherwise divested of its trade secrets,
+irrespective of what has been deposited with the U.S. Copyright Office.
+Copyright (c) 2020 Red Hat, Inc.
 */
 
 package transforms
 
 import (
-	mcm "github.com/IBM/multicloud-operators-deployable/pkg/apis/app/v1alpha1"
+	mcm "github.com/open-cluster-management/multicloud-operators-deployable/pkg/apis/apps/v1"
 )
 
+// DeployableResource ...
 type DeployableResource struct {
-	*mcm.Deployable
+	node Node
 }
 
-func (d DeployableResource) BuildNode() Node {
+// DeployableResourceBuilder ...
+func DeployableResourceBuilder(d *mcm.Deployable) *DeployableResource {
 	node := transformCommon(d)         // Start off with the common properties
 	apiGroupVersion(d.TypeMeta, &node) // add kind, apigroup and version
 	// Extract the properties specific to this type
@@ -23,9 +27,15 @@ func (d DeployableResource) BuildNode() Node {
 	node.Properties["chartUrl"] = ""
 	node.Properties["deployerNamespace"] = ""
 
-	return node
+	return &DeployableResource{node: node}
 }
 
+// BuildNode construct the node for the Deployable Resources
+func (d DeployableResource) BuildNode() Node {
+	return d.node
+}
+
+// BuildEdges construct the edges for the Deployable Resources
 func (d DeployableResource) BuildEdges(ns NodeStore) []Edge {
 	//no op for now to implement interface
 	return []Edge{}
