@@ -2,7 +2,9 @@
 IBM Confidential
 OCO Source Materials
 (C) Copyright IBM Corporation 2019 All Rights Reserved
-The source code for this program is not published or otherwise divested of its trade secrets, irrespective of what has been deposited with the U.S. Copyright Office.
+The source code for this program is not published or otherwise divested of its trade secrets,
+irrespective of what has been deposited with the U.S. Copyright Office.
+Copyright (c) 2020 Red Hat, Inc.
 */
 
 package transforms
@@ -16,7 +18,7 @@ import (
 func TestTransformDeployment(t *testing.T) {
 	var d v1.Deployment
 	UnmarshalFile("deployment.json", &d, t)
-	node := DeploymentResource{&d}.BuildNode()
+	node := DeploymentResourceBuilder(&d).BuildNode()
 
 	// Test only the fields that exist in deployment - the common test will test the other bits
 	AssertEqual("available", node.Properties["available"], int64(1), t)
