@@ -2,7 +2,9 @@
 IBM Confidential
 OCO Source Materials
 (C) Copyright IBM Corporation 2019 All Rights Reserved
-The source code for this program is not published or otherwise divested of its trade secrets, irrespective of what has been deposited with the U.S. Copyright Office.
+The source code for this program is not published or otherwise divested of its trade secrets,
+irrespective of what has been deposited with the U.S. Copyright Office.
+Copyright (c) 2020 Red Hat, Inc.
 */
 
 package transforms
@@ -17,7 +19,7 @@ import (
 func TestTransformPod(t *testing.T) {
 	var p v1.Pod
 	UnmarshalFile("pod.json", &p, t)
-	node := PodResource{&p}.BuildNode()
+	node := PodResourceBuilder(&p).BuildNode()
 
 	// Build time struct matching time in test data
 	date := time.Date(2019, 02, 21, 21, 30, 33, 0, time.UTC)
