@@ -2,7 +2,8 @@
 IBM Confidential
 OCO Source Materials
 (C) Copyright IBM Corporation 2019 All Rights Reserved
-The source code for this program is not published or otherwise divested of its trade secrets, irrespective of what has been deposited with the U.S. Copyright Office.
+The source code for this program is not published or otherwise divested of its trade secrets,
+irrespective of what has been deposited with the U.S. Copyright Office.
 */
 
 package transforms
@@ -16,7 +17,7 @@ import (
 func TestTransformReplicaSet(t *testing.T) {
 	var r v1.ReplicaSet
 	UnmarshalFile("replicaset.json", &r, t)
-	node := ReplicaSetResource{&r}.BuildNode()
+	node := ReplicaSetResourceBuilder(&r).BuildNode()
 
 	// Test only the fields that exist in replica set - the common test will test the other bits
 	AssertEqual("current", node.Properties["current"], int64(1), t)
