@@ -2,7 +2,9 @@
 IBM Confidential
 OCO Source Materials
 (C) Copyright IBM Corporation 2019 All Rights Reserved
-The source code for this program is not published or otherwise divested of its trade secrets, irrespective of what has been deposited with the U.S. Copyright Office.
+The source code for this program is not published or otherwise divested of its trade secrets,
+irrespective of what has been deposited with the U.S. Copyright Office.
+Copyright (c) 2020 Red Hat, Inc.
 */
 package transforms
 
@@ -15,7 +17,7 @@ import (
 func TestTransformService(t *testing.T) {
 	var s v1.Service
 	UnmarshalFile("service.json", &s, t)
-	node := ServiceResource{&s}.BuildNode()
+	node := ServiceResourceBuilder(&s).BuildNode()
 
 	AssertEqual("kind", node.Properties["kind"], "Service", t)
 }
