@@ -2,40 +2,43 @@
 IBM Confidential
 OCO Source Materials
 (C) Copyright IBM Corporation 2019 All Rights Reserved
-The source code for this program is not published or otherwise divested of its trade secrets, irrespective of what has been deposited with the U.S. Copyright Office.
+The source code for this program is not published or otherwise divested of its trade secrets,
+irrespective of what has been deposited with the U.S. Copyright Office.
+Copyright (c) 2020 Red Hat, Inc.
 */
 
 package transforms
 
 import (
-	"encoding/json"
+	"fmt"
 	"runtime/debug"
 	"strings"
 	"sync"
 
-	mcmapp "github.com/IBM/multicloud-operators-channel/pkg/apis/app/v1alpha1"
-	appDeployable "github.com/IBM/multicloud-operators-deployable/pkg/apis/app/v1alpha1"
-	rule "github.com/IBM/multicloud-operators-placementrule/pkg/apis/app/v1alpha1"
-	appHelmRelease "github.com/IBM/multicloud-operators-subscription-release/pkg/apis/app/v1alpha1"
-	subscription "github.com/IBM/multicloud-operators-subscription/pkg/apis/app/v1alpha1"
 	"github.com/golang/glog"
+	acmapp "github.com/open-cluster-management/multicloud-operators-channel/pkg/apis/apps/v1"
+	appDeployable "github.com/open-cluster-management/multicloud-operators-deployable/pkg/apis/apps/v1"
+	rule "github.com/open-cluster-management/multicloud-operators-placementrule/pkg/apis/apps/v1"
+	appHelmRelease "github.com/open-cluster-management/multicloud-operators-subscription-release/pkg/apis/apps/v1"
+	subscription "github.com/open-cluster-management/multicloud-operators-subscription/pkg/apis/apps/v1"
+	application "sigs.k8s.io/application/api/v1beta1"
 
-	app "github.com/kubernetes-sigs/application/pkg/apis/app/v1beta1"
-
-	com "github.com/open-cluster-management/hcm-compliance/pkg/apis/compliance/v1alpha1"
-	policy "github.com/open-cluster-management/hcm-compliance/pkg/apis/policy/v1alpha1"
+	policy "github.com/open-cluster-management/governance-policy-propagator/pkg/apis/policies/v1"
 	mcm "github.com/open-cluster-management/multicloud-operators-foundation/pkg/apis/mcm/v1alpha1"
 
-	helmRelease "github.com/open-cluster-management/helm-crd/pkg/apis/helm.bitnami.com/v1"
-
 	apps "k8s.io/api/apps/v1"
+
 	batch "k8s.io/api/batch/v1"
 	batchBeta "k8s.io/api/batch/v1beta1"
 	core "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
+	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/helm/pkg/proto/hapi/release"
+
+	ocpapp "github.com/openshift/api/apps/v1"
 )
 
+// Operation is the event operation
 type Operation int
 
 const (
@@ -83,6 +86,36 @@ type Deletion struct {
 	UID string `json:"uid,omitempty"`
 }
 
+// Builds a selfLink using data from the node. This is used as a workaround to stay compatible with
+// kubernetes 1.20 which deprecates this field.
+func buildSelfLink(nodeProps map[string]interface{}, resourceString string) string {
+	namespace := ""
+	if nodeProps["namespace"] != nil && nodeProps["namespace"].(string) != "" {
+		namespace = "/namespaces/" + nodeProps["namespace"].(string)
+	}
+
+	root := "api/v1"
+	groupVersion := ""
+	if nodeProps["apigroup"] != nil && nodeProps["apigroup"].(string) != "" &&
+		nodeProps["apiversion"] != nil && nodeProps["apiversion"].(string) != "" {
+		root = "apis"
+		groupVersion = "/" + nodeProps["apigroup"].(string) + "/" + nodeProps["apiversion"].(string)
+	} else if nodeProps["apigroup"] != nil && nodeProps["apigroup"].(string) != "" {
+		groupVersion = "/" + nodeProps["apigroup"].(string)
+	} else if nodeProps["apiversion"] != nil && nodeProps["apiversion"].(string) != "" {
+		groupVersion = "/" + nodeProps["apiversion"].(string)
+		root = "api"
+	}
+
+	// The selfLink format is: /api/apigroup/apiversion/namespaces/namespace/kind-plural/name
+	// - apigroup, version, and namespace are optional
+	// Example 1:  /api/v1/namespaces/kube-system/configmaps/cluster-config-v1
+	// Example 2:  /api/v1/nodes/ip-10-0-143-224.us-east-2.compute.internal
+	selfLink := fmt.Sprintf("/%s%s%s/%s/%s", root, groupVersion, namespace, resourceString, nodeProps["name"].(string))
+	selfLink = strings.ReplaceAll(selfLink, ":", "%3A")
+	return selfLink
+}
+
 // make new constructor here, dry up code, then start testing
 
 func NewNodeEvent(event *Event, trans Transform, resourceString string) NodeEvent {
@@ -93,6 +126,13 @@ func NewNodeEvent(event *Event, trans Transform, resourceString string) NodeEven
 		ComputeEdges: trans.BuildEdges,
 	}
 	ne.ResourceString = resourceString
+
+	// Kubernetes 1.20 deprecates selfLink. This workaround builds a self link to satisfy the existing logic.
+	// A permanent fix is delivered in ACM 2.2
+	if ne.Node.Properties["selfLink"] == nil || ne.Node.Properties["selfLink"].(string) == "" {
+		ne.Node.Properties["selfLink"] = buildSelfLink(ne.Node.Properties, resourceString)
+	}
+
 	return ne
 }
 
@@ -164,11 +204,6 @@ func TransformRoutine(input chan *Event, output chan NodeEvent) {
 		var trans Transform
 
 		event := <-input // Read from the input channel
-		// Pull out the kind and use marshal/unmarshal to convert to the right type.
-		j, err := json.Marshal(event.Resource)
-		if err != nil {
-			panic(err) // Will be caught by handleRoutineExit
-		}
 
 		// Determine apiGroup and version of the resource
 		apiGroup := ""
@@ -184,233 +219,224 @@ func TransformRoutine(input chan *Event, output chan NodeEvent) {
 		//TODO: Might have to add more transform cases if resources like DaemonSet, StatefulSet etc. have other apigroups
 		switch kindApigroup {
 		case [2]string{"Application", "app.k8s.io"}:
-			typedResource := app.Application{}
-			err = json.Unmarshal(j, &typedResource)
+			typedResource := application.Application{}
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = ApplicationResource{&typedResource}
+			trans = ApplicationResourceBuilder(&typedResource)
 
 		case [2]string{"Channel", "app.ibm.com"}, [2]string{"Channel", "apps.open-cluster-management.io"}:
-			typedResource := mcmapp.Channel{}
-			err = json.Unmarshal(j, &typedResource)
+			typedResource := acmapp.Channel{}
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = ChannelResource{&typedResource}
-
-		case [2]string{"Compliance", "compliance.mcm.ibm.com"}, [2]string{"Compliance", "apps.open-cluster-management.io"}:
-			typedResource := com.Compliance{}
-			err = json.Unmarshal(j, &typedResource)
-			if err != nil {
-				panic(err) // Will be caught by handleRoutineExit
-			}
-			trans = ComplianceResource{&typedResource}
+			trans = ChannelResourceBuilder(&typedResource)
 
 		case [2]string{"CronJob", "batch"}:
 			typedResource := batchBeta.CronJob{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = CronJobResource{&typedResource}
+			trans = CronJobResourceBuilder(&typedResource)
 
 		case [2]string{"DaemonSet", "extensions"}:
 			typedResource := apps.DaemonSet{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = DaemonSetResource{&typedResource}
+			trans = DaemonSetResourceBuilder(&typedResource)
 
 		case [2]string{"DaemonSet", "apps"}:
 			typedResource := apps.DaemonSet{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = DaemonSetResource{&typedResource}
+			trans = DaemonSetResourceBuilder(&typedResource)
 
 		case [2]string{"Deployable", "app.ibm.com"}, [2]string{"Deployable", "apps.open-cluster-management.io"}:
 			typedResource := appDeployable.Deployable{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = AppDeployableResource{&typedResource}
+			trans = AppDeployableResourceBuilder(&typedResource)
 
 		case [2]string{"Deployable", "mcm.ibm.com"}:
 			typedResource := appDeployable.Deployable{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = DeployableResource{&typedResource}
+			trans = DeployableResourceBuilder(&typedResource)
 
 		case [2]string{"Deployment", "apps"}:
 			typedResource := apps.Deployment{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = DeploymentResource{&typedResource}
+			trans = DeploymentResourceBuilder(&typedResource)
 
 		case [2]string{"Deployment", "extensions"}:
 			typedResource := apps.Deployment{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = DeploymentResource{&typedResource}
+			trans = DeploymentResourceBuilder(&typedResource)
 
-			//This is the application's HelmCR of kind HelmRelease. From 2019 Q4, the apigroup will be app.ibm.com.
-			//From 2020 Q1, the apigroup will be apps.open-cluster-management.io
-		case [2]string{"HelmRelease", "app.ibm.com"}, [2]string{"HelmRelease", "apps.open-cluster-management.io"}:
+			//This is an ocp specific resource
+		case [2]string{"DeploymentConfig", "apps.openshift.io"}:
+			typedResource := ocpapp.DeploymentConfig{}
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			if err != nil {
+				panic(err) // Will be caught by handleRoutineExit
+			}
+			trans = DeploymentConfigResourceBuilder(&typedResource)
+
+			//This is the application's HelmCR of kind HelmRelease.
+		case [2]string{"HelmRelease", "apps.open-cluster-management.io"}:
 			typedResource := appHelmRelease.HelmRelease{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = AppHelmCRResource{&typedResource}
-
-		//This is the application's HelmCR of kind HelmRelease
-		case [2]string{"HelmRelease", "helm.bitnami.com"}:
-			typedResource := helmRelease.HelmRelease{}
-			err = json.Unmarshal(j, &typedResource)
-			if err != nil {
-				panic(err) // Will be caught by handleRoutineExit
-			}
-			trans = HelmCRResource{&typedResource}
+			trans = AppHelmCRResourceBuilder(&typedResource)
 
 		case [2]string{"Job", "batch"}:
 			typedResource := batch.Job{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = JobResource{&typedResource}
+			trans = JobResourceBuilder(&typedResource)
 
 		case [2]string{"Namespace", ""}:
 			typedResource := core.Namespace{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = NamespaceResource{&typedResource}
+			trans = NamespaceResourceBuilder(&typedResource)
 
 		case [2]string{"Node", ""}:
 			typedResource := core.Node{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = NodeResource{&typedResource}
+			trans = NodeResourceBuilder(&typedResource)
 
 		case [2]string{"PersistentVolume", ""}:
 			typedResource := core.PersistentVolume{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = PersistentVolumeResource{&typedResource}
+			trans = PersistentVolumeResourceBuilder(&typedResource)
 
 		case [2]string{"PersistentVolumeClaim", ""}:
 			typedResource := core.PersistentVolumeClaim{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = PersistentVolumeClaimResource{&typedResource}
+			trans = PersistentVolumeClaimResourceBuilder(&typedResource)
 
 		case [2]string{"PlacementBinding", "mcm.ibm.com"}, [2]string{"PlacementBinding", "apps.open-cluster-management.io"}:
 			typedResource := mcm.PlacementBinding{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = PlacementBindingResource{&typedResource}
+			trans = PlacementBindingResourceBuilder(&typedResource)
 
 		case [2]string{"PlacementPolicy", "mcm.ibm.com"}, [2]string{"PlacementPolicy", "apps.open-cluster-management.io"}:
 			typedResource := mcm.PlacementPolicy{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = PlacementPolicyResource{&typedResource}
+			trans = PlacementPolicyResourceBuilder(&typedResource)
 
 		case [2]string{"PlacementRule", "app.ibm.com"}, [2]string{"PlacementRule", "apps.open-cluster-management.io"}:
 			typedResource := rule.PlacementRule{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = PlacementRuleResource{&typedResource}
+			trans = PlacementRuleResourceBuilder(&typedResource)
 
 		case [2]string{"Pod", ""}:
 			typedResource := core.Pod{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = PodResource{&typedResource}
+			trans = PodResourceBuilder(&typedResource)
 
-		case [2]string{"Policy", "policy.mcm.ibm.com"}, [2]string{"Policy", "apps.open-cluster-management.io"}:
+		case [2]string{"Policy", "policy.open-cluster-management.io"}, [2]string{"Policy", "policies.open-cluster-management.io"}:
 			typedResource := policy.Policy{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = PolicyResource{&typedResource}
+			trans = PolicyResourceBuilder(&typedResource)
 
 		case [2]string{"ReplicaSet", "apps"}:
 			typedResource := apps.ReplicaSet{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = ReplicaSetResource{&typedResource}
+			trans = ReplicaSetResourceBuilder(&typedResource)
 
 		case [2]string{"ReplicaSet", "extensions"}:
 			typedResource := apps.ReplicaSet{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = ReplicaSetResource{&typedResource}
+			trans = ReplicaSetResourceBuilder(&typedResource)
 
 		case [2]string{"Service", ""}:
 			typedResource := core.Service{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = ServiceResource{&typedResource}
+			trans = ServiceResourceBuilder(&typedResource)
 
 		case [2]string{"StatefulSet", "apps"}:
 			typedResource := apps.StatefulSet{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = StatefulSetResource{&typedResource}
+			trans = StatefulSetResourceBuilder(&typedResource)
 
 		case [2]string{"Subscription", "app.ibm.com"}, [2]string{"Subscription", "apps.open-cluster-management.io"}:
 			typedResource := subscription.Subscription{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
-			trans = SubscriptionResource{&typedResource}
+			trans = SubscriptionResourceBuilder(&typedResource)
 
 		default:
-			trans = UnstructuredResource{event.Resource}
+			trans = GenericResourceBuilder(event.Resource)
 		}
 
 		output <- NewNodeEvent(event, trans, event.ResourceString)
 
 		if IsHelmRelease(event.Resource) {
 			typedResource := core.ConfigMap{}
-			err = json.Unmarshal(j, &typedResource)
+			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
